==> nextcloud-18.0.7.tgz: nextcloud/apps/dav/l10n/de_DE.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Aufgaben",
    "Personal" : "Persönlich",
    "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
    "You created calendar {calendar}" : "Sie haben den Kalender {calendar} erstellt",
    "{actor} deleted calendar {calendar}" : "{actor} hat den Kalender {calendar} gelöscht",
    "You deleted calendar {calendar}" : "Sie haben den Kalender {calendar} gelöscht",
    "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
    "You updated calendar {calendar}" : "Sie haben hat den Kalender {calendar} aktualisiert",
    "You shared calendar {calendar} as public link" : "Sie haben den Kalender {calendar} als öffentlichen Link geteilt",
    "You removed public link for calendar {calendar}" : "Sie haben den öffentlichen Link für Kalender {calendar} entfernt",
    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit Ihnen geteilt",
    "You shared calendar {calendar} with {user}" : "Sie haben den Kalender {calendar} mit {user} geteilt",
    "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit Ihnen",
    "You unshared calendar {calendar} from {user}" : "Sie teilen den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
    "You shared calendar {calendar} with group {group}" : "Sie haben den Kalender {calendar} mit der Gruppe {group} geteilt",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Sie teilen den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} erstellt",
    "You created event {event} in calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} erstellt",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} gelöscht",
    "You deleted event {event} from calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} gelöscht",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} aktualisiert",
    "You updated event {event} in calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} aktualisiert",
    "Busy" : "Beschäftigt",
    "{actor} created todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
    "You created todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erstellt",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "You deleted todo {todo} from list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "You updated todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
    "You solved todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erledigt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "You reopened todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
    "A calendar <strong>event</strong> was modified" : "Ein Kalender-<strong>Termin</strong> wurde bearbeitet",
    "A calendar <strong>todo</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde bearbeitet",
    "Death of %s" : "Todestag von %s",
    "Contact birthdays" : "Geburtstage von Kontakten",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Wo:",
    "Description:" : "Beschreibung:",
    "Untitled event" : "Termin ohne Titel",
    "_%n year_::_%n years_" : ["%n Jahr","%n Jahre"],
    "_%n month_::_%n months_" : ["%n Monat","%n Monate"],
    "_%n day_::_%n days_" : ["%n Tag","%n Tage"],
    "_%n hour_::_%n hours_" : ["%n Stunde","%n Stunden"],
    "_%n minute_::_%n minutes_" : ["%n Minute","%n Minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (vor %s)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschreibung: %s",
    "Where: %s" : "Ort: %s",
    "%1$s via %2$s" : "%1$s über %2$s",
    "Invitation canceled" : "Einladung abgebrochen",
    "Hello %s," : "Hallo %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Der Termin »%1$s« mit %2$s wurde abgesagt.",
    "Invitation updated" : "Einladung aktualisiert",
    "The meeting »%1$s« with %2$s was updated." : "Der Termin »%1$s« mit %2$s wurde aktualisiert.",
    "%1$s invited you to »%2$s«" : "%1$s hat Sie zu »%2$s« eingeladen",
    "When:" : "Wann:",
    "Link:" : "Link:",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "More options …" : "Weitere Optionen...",
    "More options at %s" : "Weitere Optionen unter %s",
    "Contacts" : "Kontakte",
    "System in maintenance mode." : "Das System befindet sich im Wartungsmodus.",
    "Upgrade needed" : "Aktualisierung erforderlich",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ihr %s muss konfiguriert werden, um HTTPS zusammen mit CalDAV und CardDAV unter iOS/macOS nutzen zu können.",
    "Configures a CalDAV account" : "Ein CalDAV-Konto einrichten",
    "Configures a CardDAV account" : "Ein CardDAV-Konto einrichten",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-Endpunkt",
    "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren Ihres Teilnehmerstatus aufgetreten.",
    "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
    "Are you accepting the invitation?" : "Die Einladung annehmen?",
    "Tentative" : "Vorläufig",
    "Save" : "Speichern",
    "Your attendance was updated successfully." : "Ihr Teilnehmerstatus wurde aktualisiert.",
    "Calendar server" : "Kalender-Server",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installieren Sie außerdem die {calendarappstoreopen}Kalender-App{linkclose}, oder {calendardocopen}verbinden Sie Ihren Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
    "Send invitations to attendees" : "Einladungen an die Teilnehmer versenden",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stellen Sie sicher, dass Sie {emailopen}den E-Mail Server{linkclose} ordnungsgemäß einrichtet haben.",
    "Automatically generate a birthday calendar" : "Automatisch einen Kalender für Geburtstage erstellen",
    "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einem Hintergrund-Auftrag erstellt",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es ein wenig dauern bis zur Anzeige.",
    "Send notifications for events" : "Sende Benachrichtigungen für Termine",
    "Notifications are sent via background jobs, so these must occur often enough." : "Benachrichtigungen werden von Hintergrundjobs versendet, so dass diese häufig genug ausgeführt werden müssen.",
    "Enable notifications for events via push" : "Benachrichtigungen für Ereignisse per Push aktivieren",
    "Technical details" : "Technische Details",
    "Remote Address: %s" : "Entfernte Adresse: %s",
    "Request ID: %s" : "Anfragekennung: %s",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Benachrichtigungen werden von Hintergrundjobs versendet, so dass diese häufig genug ausgeführt werden müssen."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.8.tgz: nextcloud/apps/dav/l10n/de_DE.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalender",
    "Todos" : "Aufgaben",
    "Personal" : "Persönlich",
    "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
    "You created calendar {calendar}" : "Sie haben den Kalender {calendar} erstellt",
    "{actor} deleted calendar {calendar}" : "{actor} hat den Kalender {calendar} gelöscht",
    "You deleted calendar {calendar}" : "Sie haben den Kalender {calendar} gelöscht",
    "{actor} updated calendar {calendar}" : "{actor} hat den Kalender {calendar} aktualisiert",
    "You updated calendar {calendar}" : "Sie haben hat den Kalender {calendar} aktualisiert",
    "You shared calendar {calendar} as public link" : "Sie haben den Kalender {calendar} als öffentlichen Link geteilt",
    "You removed public link for calendar {calendar}" : "Sie haben den öffentlichen Link für Kalender {calendar} entfernt",
    "{actor} shared calendar {calendar} with you" : "{actor} hat den Kalender {calendar} mit Ihnen geteilt",
    "You shared calendar {calendar} with {user}" : "Sie haben den Kalender {calendar} mit {user} geteilt",
    "{actor} shared calendar {calendar} with {user}" : "{actor} hat den Kalender {calendar} mit {user} geteilt",
    "{actor} unshared calendar {calendar} from you" : "{actor} teilt den Kalender {calendar} nicht mehr mit Ihnen",
    "You unshared calendar {calendar} from {user}" : "Sie teilen den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} teilt den Kalender {calendar} nicht mehr mit {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} teilt den Kalender {calendar} nicht mehr mit sich selbst",
    "You shared calendar {calendar} with group {group}" : "Sie haben den Kalender {calendar} mit der Gruppe {group} geteilt",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} teilt den Kalender {calendar} mit der Gruppe {group}",
    "You unshared calendar {calendar} from group {group}" : "Sie teilen den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} teilt den Kalender {calendar} nicht mehr mit der Gruppe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} erstellt",
    "You created event {event} in calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} erstellt",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} gelöscht",
    "You deleted event {event} from calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} gelöscht",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} hat den Termin {event} im Kalender {calendar} aktualisiert",
    "You updated event {event} in calendar {calendar}" : "Sie haben den Termin {event} im Kalender {calendar} aktualisiert",
    "Busy" : "Beschäftigt",
    "{actor} created todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erstellt",
    "You created todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erstellt",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "You deleted todo {todo} from list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} gelöscht",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "You updated todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} aktualisiert",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} erledigt",
    "You solved todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} erledigt",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} hat die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "You reopened todo {todo} in list {calendar}" : "Sie haben die Aufgabe {todo} in der Liste {calendar} wiedereröffnet",
    "A <strong>calendar</strong> was modified" : "Ein <strong>Kalender</strong> wurde bearbeitet",
    "A calendar <strong>event</strong> was modified" : "Ein Kalender-<strong>Termin</strong> wurde bearbeitet",
    "A calendar <strong>todo</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde bearbeitet",
    "Death of %s" : "Todestag von %s",
    "Contact birthdays" : "Geburtstage von Kontakten",
    "Calendar:" : "Kalender:",
    "Date:" : "Datum:",
    "Where:" : "Wo:",
    "Description:" : "Beschreibung:",
    "Untitled event" : "Termin ohne Titel",
    "_%n year_::_%n years_" : ["%n Jahr","%n Jahre"],
    "_%n month_::_%n months_" : ["%n Monat","%n Monate"],
    "_%n day_::_%n days_" : ["%n Tag","%n Tage"],
    "_%n hour_::_%n hours_" : ["%n Stunde","%n Stunden"],
    "_%n minute_::_%n minutes_" : ["%n Minute","%n Minuten"],
    "%s (in %s)" : "%s (in %s)",
    "%s (%s ago)" : "%s (vor %s)",
    "Calendar: %s" : "Kalender: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Beschreibung: %s",
    "Where: %s" : "Ort: %s",
    "%1$s via %2$s" : "%1$s über %2$s",
    "Invitation canceled" : "Einladung abgebrochen",
    "Hello %s," : "Hallo %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Der Termin »%1$s« mit %2$s wurde abgesagt.",
    "Invitation updated" : "Einladung aktualisiert",
    "The meeting »%1$s« with %2$s was updated." : "Der Termin »%1$s« mit %2$s wurde aktualisiert.",
    "%1$s invited you to »%2$s«" : "%1$s hat Sie zu »%2$s« eingeladen",
    "When:" : "Wann:",
    "Link:" : "Link:",
    "Accept" : "Akzeptieren",
    "Decline" : "Ablehnen",
    "More options …" : "Weitere Optionen...",
    "More options at %s" : "Weitere Optionen unter %s",
    "Contacts" : "Kontakte",
    "System in maintenance mode." : "Das System befindet sich im Wartungsmodus.",
    "Upgrade needed" : "Aktualisierung erforderlich",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Ihr %s muss konfiguriert werden, um HTTPS zusammen mit CalDAV und CardDAV unter iOS/macOS nutzen zu können.",
    "Configures a CalDAV account" : "Ein CalDAV-Konto einrichten",
    "Configures a CardDAV account" : "Ein CardDAV-Konto einrichten",
    "Events" : "Ereignisse",
    "Tasks" : "Aufgaben",
    "Untitled task" : "Unbenannte Aufgabe",
    "Completed on %s" : "Erledigt am %s",
    "Due on %s by %s" : "Fällig am %s von %s",
    "Due on %s" : "Fällig am %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV-Endpunkt",
    "There was an error updating your attendance status." : "Es ist ein Fehler beim Aktualisieren Ihres Teilnehmerstatus aufgetreten.",
    "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
    "Are you accepting the invitation?" : "Die Einladung annehmen?",
    "Tentative" : "Vorläufig",
    "Save" : "Speichern",
    "Your attendance was updated successfully." : "Ihr Teilnehmerstatus wurde aktualisiert.",
    "Calendar server" : "Kalender-Server",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installieren Sie außerdem die {calendarappstoreopen}Kalender-App{linkclose}, oder {calendardocopen}verbinden Sie Ihren Desktop & Mobilgerät zur Synchronisierung ↗{linkclose}.",
    "Send invitations to attendees" : "Einladungen an die Teilnehmer versenden",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Bitte stellen Sie sicher, dass Sie {emailopen}den E-Mail Server{linkclose} ordnungsgemäß einrichtet haben.",
    "Automatically generate a birthday calendar" : "Automatisch einen Kalender für Geburtstage erstellen",
    "Birthday calendars will be generated by a background job." : "Kalender für Geburtstage werden von einem Hintergrund-Auftrag erstellt",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Die Einträge werden nicht sofort angezeigt. Nach der Aktivierung wird es ein wenig dauern bis zur Anzeige.",
    "Send notifications for events" : "Sende Benachrichtigungen für Termine",
    "Notifications are sent via background jobs, so these must occur often enough." : "Benachrichtigungen werden von Hintergrundjobs versendet, so dass diese häufig genug ausgeführt werden müssen.",
    "Enable notifications for events via push" : "Benachrichtigungen für Ereignisse per Push aktivieren",
    "Technical details" : "Technische Details",
    "Remote Address: %s" : "Entfernte Adresse: %s",
    "Request ID: %s" : "Anfragekennung: %s",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Benachrichtigungen werden von Hintergrundjobs versendet, so dass diese häufig genug ausgeführt werden müssen."
},
"nplurals=2; plural=(n != 1);");
